@@ -1,23 +1,30 @@
+from math import pi
+from pathlib import Path
+from typing import Optional, Union, List, Tuple, Iterable
+
+import matplotlib.pyplot as plt
+from matplotlib.axes import Axes
+from matplotlib.collections import PathCollection
+from matplotlib.font_manager import FontProperties
+from matplotlib.patches import Rectangle, RegularPolygon, Circle, Arc, Arrow, \
+    Ellipse, FancyArrow, Patch, FancyArrowPatch
+from matplotlib.path import Path
 from pandas import DataFrame
 
 from compound_types.arrays import ArrayLike
 from compound_types.built_ins import FloatOrFloatIterable, StrOrStrIterable, \
     DictOrDictIterable
-import matplotlib.pyplot as plt
-from matplotlib.axes import Axes
-from matplotlib.collections import PathCollection
-from matplotlib.font_manager import FontProperties
-from matplotlib.patches import Rectangle
 from mpl_format.axes.axis_formatter import AxisFormatter
 from mpl_format.axes.axis_utils import new_axes
-from mpl_format.compound_types import FontSize, Color, LegendLocation
+from mpl_format.compound_types import FontSize, Color, LegendLocation, \
+    StringMapper
 from mpl_format.io_utils import save_plot
 from mpl_format.legend.legend_formatter import LegendFormatter
 from mpl_format.patches.patch_list_formatter import PatchListFormatter
+from mpl_format.styles import LINE_STYLE, CAP_STYLE, JOIN_STYLE, ARROW_STYLE, \
+    CONNECTION_STYLE
 from mpl_format.text.text_formatter import TextFormatter
 from mpl_format.text.text_utils import wrap_text
-from pathlib import Path
-from typing import Optional, Union, Dict, Callable, List, Tuple, Iterable
 
 
 class AxesFormatter(object):
@@ -98,7 +105,7 @@ class AxesFormatter(object):
         return self
 
     def map_title_text(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the label text for the title using a dictionary or function.
@@ -177,6 +184,17 @@ class AxesFormatter(object):
         self.y_axis.wrap_label(max_width=max_width)
         return self
 
+    def wrap_axis_labels(self, max_width: int) -> 'AxesFormatter':
+        """
+        Wrap the texts for the x and y-axis labels if they exceeds a given width
+        of characters.
+
+        :param max_width: The maximum character width per line.
+        """
+        self.wrap_x_label(max_width=max_width)
+        self.wrap_y_label(max_width=max_width)
+        return self
+
     def wrap_x_tick_labels(self, max_width: int) -> 'AxesFormatter':
         """
         Wrap the text for each tick label on the x-axis with new lines if it
@@ -319,7 +337,7 @@ class AxesFormatter(object):
     # region map labels
 
     def map_x_axis_label(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the label text for the x-axis using a dictionary or function.
@@ -330,7 +348,7 @@ class AxesFormatter(object):
         return self
 
     def map_y_axis_label(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the label text for the y-axis using a dictionary or function.
@@ -341,7 +359,7 @@ class AxesFormatter(object):
         return self
 
     def map_axis_labels(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the label text for the x and y axes using a dictionary or function.
@@ -353,7 +371,7 @@ class AxesFormatter(object):
         return self
 
     def map_x_tick_labels(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the tick label text for the x-axis using a dictionary or function.
@@ -364,7 +382,7 @@ class AxesFormatter(object):
         return self
 
     def map_y_tick_labels(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the tick label text for the y-axis using a dictionary or function.
@@ -375,7 +393,7 @@ class AxesFormatter(object):
         return self
 
     def map_tick_labels(
-            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+            self, mapping: StringMapper
     ) -> 'AxesFormatter':
         """
         Map the tick label text using a dictionary or function.
@@ -401,8 +419,10 @@ class AxesFormatter(object):
         """
         Remove the legend from the Axes.
         """
-        self._axes.get_legend().remove()
-        self._legend = None
+        legend = self._axes.get_legend()
+        if legend is not None:
+            legend.remove()
+            self._legend = None
         return self
 
     def remove_x_ticks(self) -> 'AxesFormatter':
@@ -419,6 +439,14 @@ class AxesFormatter(object):
         self._axes.set_yticks([])
         return self
 
+    def remove_axes_ticks(self) -> 'AxesFormatter':
+        """
+        Remove x- and y- ticks from the Axes.
+        """
+        self.remove_x_ticks()
+        self.remove_y_ticks()
+        return self
+
     def remove_x_label(self) -> 'AxesFormatter':
         """
         Remove the label from the x-axis.
@@ -433,6 +461,14 @@ class AxesFormatter(object):
         self.y_axis.remove_label()
         return self
 
+    def remove_axes_labels(self) -> 'AxesFormatter':
+        """
+        Remove the labels from the x- and y- axes.
+        """
+        self.remove_x_label()
+        self.remove_y_label()
+        return self
+
     # endregion
 
     # region rotation
@@ -771,6 +807,526 @@ class AxesFormatter(object):
             )
         return self
 
+    def add_arc(
+            self, x: float, y: float, width: float, height: float,
+            angle: float = 0.0,
+            theta_start: float = 0.0, theta_end: float = 360.0,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None
+    ):
+        """
+        Add an elliptical arc, i.e. a segment of an ellipse.
+
+        :param x: The x-coordinate of the center of the ellipse.
+        :param y: The y-coordinate of the center of the ellipse.
+        :param width: The length of the horizontal axis.
+        :param height: The length of the vertical axis.
+        :param angle: Rotation of the ellipse in degrees (counterclockwise).
+        :param theta_start: Starting angle of the arc in degrees.
+                            Relative to angle, e.g. if angle = 45 and
+                            theta_start = 90 the absolute starting angle is 135.
+        :param theta_end: Ending angle of the arc in degrees.
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        arc = Arc(
+            xy=(x, y), width=width, height=height,
+             angle=angle, theta1=theta_start, theta2=theta_end,
+            **kwargs
+        )
+        self._axes.add_artist(arc)
+        return self
+
+    def add_arrow(
+            self, x: float, y: float, dx: float, dy: float,
+            width: float = 1.0,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None
+    ):
+        """
+        Add an an arrow patch.
+
+        :param x: The x-coordinate of the arrow tail.
+        :param y: The y-coordinate of the arrow tail.
+        :param dx: Arrow length in the x direction.
+        :param dy: Arrow length in the y direction.
+        :param width: Scale factor for the width of the arrow.
+                      With a default value of 1, the tail width is 0.2 and
+                      head width is 0.6.
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        arrow = Arrow(
+            x=x, y=y, dx=dx, dy=dy, width=width,
+            **kwargs
+        )
+        self._axes.add_artist(arrow)
+        return self
+
+    def add_circle(
+            self, x: float, y: float,
+            radius: float,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None
+    ) -> 'AxesFormatter':
+        """
+        Add a rectangle to the Axes.
+
+        :param x: The left rectangle coordinate.
+        :param y: The bottom rectangle coordinate.
+        :param radius: The radius of the circle.
+        :param alpha: Opacity.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        :param cap_style: Cap style.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        polygon = Circle(
+            xy=(x, y), radius=radius,
+            **kwargs
+        )
+        self._axes.add_artist(polygon)
+        return self
+
+    def add_ellipse(
+            self, x: float, y: float, width: float, height: float,
+            angle: float = 0.0,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None
+    ):
+        """
+        Add an elliptical arc, i.e. a segment of an ellipse.
+
+        :param x: The x-coordinate of the center of the ellipse.
+        :param y: The y-coordinate of the center of the ellipse.
+        :param width: The length (diameter) of the horizontal axis.
+        :param height: The length (diameter) of the vertical axis.
+        :param angle: Rotation of the ellipse in degrees (counterclockwise).
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        ellipse = Ellipse(
+            xy=(x, y), width=width, height=height, angle=angle,
+            **kwargs
+        )
+        self._axes.add_artist(ellipse)
+        return self
+
+    def add_fancy_arrow(
+            self, x: float, y: float, dx: float, dy: float,
+            width: float = 0.001,
+            length_includes_head: bool = False,
+            head_width: Optional[float] = None,
+            head_length: Optional[float] = None,
+            shape: str = 'full',
+            overhang: float = 0.0,
+            head_starts_at_zero: bool = False,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None
+    ):
+        """
+        Like Arrow, but lets you set head width and head height independently.
+
+        :param x: The x-coordinate of the arrow tail.
+        :param y: The y-coordinate of the arrow tail.
+        :param dx: Arrow length in the x direction.
+        :param dy: Arrow length in the y direction.
+        :param width: Width of full arrow tail.
+        :param length_includes_head: True if head is to be counted in
+                                     calculating the length.
+        :param head_width: Total width of the full arrow head
+        :param head_length: Length of arrow head
+        :param shape: Draw the left-half, right-half, or full arrow.
+                      One of ['full', 'left', 'right'].
+        :param overhang: Fraction that the arrow is swept back
+                         (0 overhang means triangular shape).
+                         Can be negative or greater than one.
+        :param head_starts_at_zero: If True, the head starts being drawn at
+                                    coordinate 0 instead of ending at
+                                    coordinate 0.
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        arrow = FancyArrow(
+            x=x, y=y, dx=dx, dy=dy, width=width,
+            length_includes_head=length_includes_head,
+            head_width=head_width,
+            head_length=head_length,
+            shape=shape,
+            overhang=overhang,
+            head_starts_at_zero=head_starts_at_zero,
+            **kwargs
+        )
+        self._axes.add_artist(arrow)
+        return self
+
+    def add_fancy_arrow_patch(
+            self, x: float, y: float, dx: float, dy: float,
+            path: Optional[Path] = None,
+            arrow_style: Union[str, ARROW_STYLE] = 'simple',
+            connection_style: Union[str, CONNECTION_STYLE] = 'arc3',
+            tail_patch: Optional[Patch] = None,
+            head_patch: Optional[Patch] = None,
+            tail_shrink_factor: Optional[float] = 2,
+            head_shrink_factor: Optional[float] = 2,
+            mutation_scale: Optional[float] = 1,
+            mutation_aspect: Optional[float] = None,
+            dpi_cor: Optional[float] = 1,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None
+    ):
+        """
+        Like Arrow, but lets you set head width and head height independently.
+
+        :param x: The x-coordinate of the arrow tail.
+        :param y: The y-coordinate of the arrow tail.
+        :param dx: Arrow length in the x direction.
+        :param dy: Arrow length in the y direction.
+        :param path: If provided, an arrow is drawn along this path and
+                     tail_patch, head_patch, tail_shrink_factor, and
+                     head_shrink_factor are ignored.
+        :param arrow_style: Describes how the fancy arrow will be drawn.
+                            It can be string of the available arrowstyle names,
+                            with optional comma-separated attributes,
+                            or an ArrowStyle instance.
+                            The optional attributes are meant to be scaled with
+                            the mutation_scale.
+        :param connection_style: Describes how the arrow ends are connected.
+        :param tail_patch: Optional tail patch.
+        :param head_patch: Optional head patch.
+        :param tail_shrink_factor: Shrinking factor of the tail.
+        :param head_shrink_factor: Shrinking factor of the head.
+        :param mutation_scale: Value with which attributes of arrowstyle
+                               (e.g., head_length) will be scaled.
+        :param mutation_aspect: The height of the rectangle will be squeezed by
+                                this value before the mutation and the mutated
+                                box will be stretched by the inverse of it.
+        :param dpi_cor: dpi_cor is currently used for linewidth-related things
+                        and shrink factor. Mutation scale is affected by this.
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        if arrow_style and isinstance(arrow_style, ARROW_STYLE):
+            arrow_style = arrow_style.get_name()
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        arrow = FancyArrowPatch(
+            posA=(x, y), posB=(x + dx, y + dy),
+            path=path, arrowstyle=arrow_style,
+            connectionstyle=connection_style,
+            patchA=tail_patch, patchB=head_patch,
+            shrinkA=tail_shrink_factor, shrinkB=head_shrink_factor,
+            mutation_scale=mutation_scale, mutation_aspect=mutation_aspect,
+            dpi_cor=dpi_cor,
+            **kwargs
+        )
+        self._axes.add_artist(arrow)
+        return self
+
+    def add_rectangle(
+            self, x: float, y: float, width: float, height: float,
+            angle: float = 0.0,
+            alpha: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None
+    ) -> 'AxesFormatter':
+        """
+        Add a rectangle to the Axes.
+
+        :param x: The left rectangle coordinate.
+        :param y: The bottom rectangle coordinate.
+        :param width: Rectangle width.
+        :param height: Rectangle height.
+        :param angle: Rotation in degrees anti-clockwise about xy
+                      (default is 0.0)
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        rectangle = Rectangle(
+            xy=(x, y), width=width, height=height, angle=angle,
+            **kwargs
+        )
+        self._axes.add_artist(rectangle)
+        return self
+
+    def add_regular_polygon(
+            self, x: float, y: float,
+            num_vertices: int,
+            radius: float,
+            angle: float = 0,
+            alpha: Optional[float] = None,
+            color: Optional[Color] = None,
+            edge_color: Optional[Color] = None,
+            face_color: Optional[Color] = None,
+            fill: bool = True,
+            label: Optional[str] = None,
+            line_style: Optional[Union[str, LINE_STYLE]] = None,
+            line_width: Optional[float] = None,
+            cap_style: Optional[Union[str, CAP_STYLE]] = None,
+            join_style: Optional[Union[str, JOIN_STYLE]] = None
+    ) -> 'AxesFormatter':
+        """
+        Add a rectangle to the Axes.
+
+        :param x: The left rectangle coordinate.
+        :param y: The bottom rectangle coordinate.
+        :param num_vertices: Number of vertices.
+        :param radius: The distance from the center to each of the vertices.
+        :param angle: Rotation in degrees anti-clockwise about xy
+                            (default is 0.0)
+        :param alpha: Opacity.
+        :param cap_style: Cap style.
+        :param color: Use to set both the edge-color and the face-color.
+        :param edge_color: Edge color.
+        :param face_color: Face color.
+        :param fill: Whether to fill the rectangle.
+        :param join_style: Join style.
+        :param label: Label for the object in the legend.
+        :param line_style: Line style for edge.
+        :param line_width: Line width for edge.
+        """
+        if line_style and isinstance(line_style, LINE_STYLE):
+            line_style = line_style.name
+        if cap_style and isinstance(cap_style, CAP_STYLE):
+            cap_style = cap_style.name
+        if join_style and isinstance(join_style, JOIN_STYLE):
+            join_style = join_style.name
+        # convert args to matplotlib names
+        kwargs = {}
+        for arg, mpl_arg in zip(
+            [alpha, cap_style, color, edge_color, face_color,
+             fill, join_style, label, line_style, line_width],
+            ['alpha', 'capstyle', 'color', 'edgecolor', 'facecolor',
+             'fill', 'joinstyle', 'label', 'linestyle', 'linewidth']
+        ):
+            if arg is not None:
+                kwargs[mpl_arg] = arg
+        polygon = RegularPolygon(
+            xy=(x, y), numVertices=num_vertices, radius=radius,
+            orientation=pi * angle / 180,
+            **kwargs
+        )
+        self._axes.add_artist(polygon)
+        return self
+
     # endregion
 
     def set_title_font_family(self, font_name: str) -> 'AxesFormatter':
@@ -872,13 +1428,13 @@ class AxesFormatter(object):
 
     # endregion
 
-    def grid(self, value: bool,
+    def grid(self, value: bool = True,
              which: str = 'major',
              axis: str = 'both') -> 'AxesFormatter':
         """
         Turn the grid on or off.
 
-        :param value: True or False
+        :param value: True or False. Defaults to True.
         :param which: 'major', 'minor' or 'both'
         :param axis: 'x', 'y' or 'both
         """
@@ -897,12 +1453,13 @@ class AxesFormatter(object):
 
     def save(self,
              file_path: Union[str, Path],
-             file_type: str = 'png') -> 'AxesFormatter':
+             file_type: Optional[str] = None) -> 'AxesFormatter':
         """
         Save the plot to disk.
 
         :param file_path: The file path to save the plot object to.
         :param file_type: The type of file to save.
+                          Defaults to png if can't be auto-detected from name.
         """
         save_plot(plot_object=self._axes,
                   file_path=file_path,
@@ -1053,9 +1610,9 @@ class AxesFormatter(object):
         self._legend = LegendFormatter(self._axes.legend(**kwargs))
         return self._legend
 
-    @staticmethod
-    def show():
+    def show(self) -> 'AxesFormatter':
         """
         Show the figure for the axes.
         """
         plt.show()
+        return self
